" Vim syntax file
" Language:     Csound unified file (CSD)
" Maintainer:   Istvan Varga
" Last change:  Jan 2 2003

syn	clear

" reserved variables (sr etc.) and opcodes

syn	keyword	Identifier	sr kr ksmps nchnls 0dbfs
syn	keyword	Statement	instr endin opcode endop
syn	keyword	Statement	if then else elseif endif

" score statements (f, t, i etc.)

syn	match	Statement	"^[ \t]*[[:alpha:]]\>"

" CSD tags

hi	link	CSDTag		Statement

syn	keyword	CSDTag		CsoundSynthesizer
syn	keyword	CSDTag		CsVersion
syn	keyword	CSDTag		CsOptions
syn	keyword	CSDTag		CsInstruments
syn	keyword	CSDTag		CsScore
syn	keyword	CSDTag		CsMidifile
syn	keyword	CSDTag		CsMidifileB
syn	keyword	CSDTag		CsSampleB
syn	keyword	CSDTag		CsFileB

syn	match	Identifier	"<[[:alnum:]]\+>" contains=CSDTag
syn	match	Identifier	"</[[:alnum:]]\+>" contains=CSDTag

" set installation directory here

source	'/usr/local/share/vim/syntax/Csound_opcodes.vim'

" comments

syn	region	Comment	start="/\*" end="\*/"
syn	match	Comment ";.*$"

" backslash

syn	match	Special	"\\$"
syn	match	Special "\\."

" labels

syn	match	Label		"^[[:space:]]*[[:alnum:]_]\+:"

" variable types

syn	match	Type	"\<[akip]"
syn	match	Type	"\<g[aki]"

" constants

syn	match	Constant	"\<[[:digit:]]\+\(\.[[:digit:]]\+\)\{,1\}\([Ee][+-]\{,1\}[[:digit:]]\+\)\{,1\}\>"
syn	match	Constant	"\".*\""

" include files and macros

syn	match	PreProc	"#"
syn	match	PreProc	"#include"
syn	match	PreProc	"#define"
syn	match	PreProc	"#define[^#]*#"
syn	match	PreProc	"#undef.*$"
syn	match	PreProc	"\$[[:alpha:]][[:alnum:]_]*\(([^()]*)\)\{,1\}\.\{,1\}"

" some useful keyboard shortcuts

" F1: orchestra header (mono)

map!	<F1>	sr<TAB>=  48000<CR>ksmps<TAB>=  32<CR>nchnls<TAB>=  1<CR>0dbfs<TAB>=  1<CR><CR>

" F2: orchestra header (stereo)

map!	<F2>	sr<TAB>=  48000<CR>ksmps<TAB>=  32<CR>nchnls<TAB>=  2<CR>0dbfs<TAB>=  1<CR><CR>

" F4: orchestra header (quad)

map!	<F4>	sr<TAB>=  48000<CR>ksmps<TAB>=  32<CR>nchnls<TAB>=  4<CR>0dbfs<TAB>=  1<CR><CR>

" F3: include files

map!	<F3>	#include "base_macros.h.orc"<CR>#include "fgen.h.orc"<CR>#include "spat.h.orc"<CR>#include "uhjmacros.h.orc"<CR>#include "ctrl.h.orc"<CR><CR>

" F5: score instrument template (mono)

map!	<F5>	<TAB>instr 1<CR><Home><Del><CR>$S_NOTEPARM(0.05'0.02)<CR><CR>a1<TAB>oscils 0.5 * iamp, icps, 0<CR>a1<TAB>=  a1 * (aenv * aenv)<CR><CR><TAB>out a1<CR><CR>endin<CR><Home><Del><CR>

" F6: MIDI instrument template (mono)

map!	<F6>	<TAB>instr 1<CR><Home><Del><CR>$M_NOTEPARM(0.05'0.02)<CR><CR>a1<TAB>oscils 0.5 * iamp, icps, 0<CR>a1<TAB>=  a1 * (aenv * aenv)<CR><CR><TAB>out a1<CR><CR>endin<CR><Home><Del><CR>

" F7: score instrument template (stereo)

map!	<F7>	<TAB>instr 1<CR><Home><Del><CR>$S_NOTEPARM(0.05'0.2)<CR><CR>a1<TAB>oscils 0.5 * iamp, icps, 0<CR>a1<TAB>=  a1 * (aenv * aenv)<CR><CR>$SPAT2(a1'0'0.6)<CR><CR><TAB>endin<CR><Home><Del><CR>

" F8: MIDI instrument template (stereo)

map!	<F8>	<TAB>instr 1<CR><Home><Del><CR>$M_NOTEPARM(0.05'0.2)<CR><CR>a1<TAB>oscils 0.5 * iamp, icps, 0<CR>a1<TAB>=  a1 * (aenv * aenv)<CR><CR>$SPAT2(a1'0'0.6)<CR><CR><TAB>endin<CR><Home><Del><CR>

" F9: output instr (2+1 chn)

map!	<F9>	$OUT3CH(90'"/dev/null")<CR><CR>

" F10: output instr (4 chn)

map!	<F10>	$OUT4CH(90)<CR><CR>

" F11: generate band-limited sawtooth waves (used in orc header)

map!	<F11>	; sawtooth wave<CR>itmp<TAB>ftgen 257, 0, 16384, 7, 1, 16384, -1<CR>$FGEN_128(l1'256'4096'257'1'sr/2)<CR><CR>

" F12: assign MIDI channels

map!	<F12>	<TAB>massign  1, 11<TAB><TAB>; assign MIDI channels<CR><Home><Del><TAB>massign  2, 12<CR><Home><Del><TAB>massign  3, 13<CR><Home><Del><TAB>massign  4, 14<CR><Home><Del><TAB>massign  5, 15<CR><Home><Del><TAB>massign  6, 16<CR><Home><Del><TAB>massign  7, 17<CR><Home><Del><TAB>massign  8, 18<CR><Home><Del><TAB>massign  9, 19<CR><Home><Del><TAB>massign 10, 20<CR><Home><Del><TAB>massign 11, 21<CR><Home><Del><TAB>massign 12, 22<CR><Home><Del><TAB>massign 13, 23<CR><Home><Del><TAB>massign 14, 24<CR><Home><Del><TAB>massign 15, 25<CR><Home><Del><TAB>massign 16, 26<CR><Home><Del><CR><TAB>pgmassign 0, 0<TAB><TAB>; disable program changes<CR><Home><Del><CR>

